"""ctparse - parse time expressions in strings

.. moduleauthor:: Comtravo

"""
__author__ = """Sebastian Mika"""
__email__ = "sebastian.mika@comtravo.com"
__version__ = "__version__ = '0.3.3'"

from ctparse.ctparse import ctparse, ctparse_gen  # noqa
